from distutils.core import setup
setup(
  name = 'ml_easy_peer_grade',
  packages = ['ml_easy_peer_grade'], 
  version = '0.16',
  scripts=['bin/ml_easy_peer_grade'],
  description = 'Ez peer grade your project members, exclusive to privileged Bilkent students',
  author = 'Cagdas Oztekin',
  author_email = 'lorrabarra@gmail.com',
  url = 'https://github.com/cagdass/ml-easy-peer-grade', 
  download_url = 'https://github.com/cagdass/ml-easy-peer-grade/tarball/0.1',
  keywords = ['testing'],
  classifiers = [],
)
